#ifndef NT2_INCLUDE_FUNCTIONS_GCD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GCD_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/gcd.hpp>

#endif
